==> haskell-genvalidity-hspec-1.0.0.4-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.4
visibility:           public
id:                   genvalidity-hspec-1.0.0.4-ESHLPFe50XqCJlhLbo11kW
key:                  genvalidity-hspec-1.0.0.4-ESHLPFe50XqCJlhLbo11kW
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  6da93f9fa04b236d229dabac4b238d44
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.4-ESHLPFe50XqCJlhLbo11kW
depends:
    QuickCheck-2.14.3-Jxw7miv7LXh9Jg8jeeWydd base-4.17.2.1
    genvalidity-1.1.1.0-7bIVcR4TVXBJNEIpRzWFvJ
    genvalidity-property-1.0.0.0-5GCulqYfZZKEVu3ivP9Y16
    hspec-2.10.10-GABSAcS03JI8KBYWkKpU7p
    hspec-core-2.10.10-Ax2BJPDamQH4fAu4Te7xmH transformers-0.5.6.2
    validity-0.12.1.0-KOm1FOv5J31ERKsDZQThz7

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-hspec-1.0.0.4-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-hspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.4
visibility:           public
id:                   genvalidity-hspec-1.0.0.4-BFGTO98ZQdkEXvacZWa8Gr
key:                  genvalidity-hspec-1.0.0.4-BFGTO98ZQdkEXvacZWa8Gr
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  6cbdc7934e9ac97e8df2776dab4a2b40
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-hspec-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.4-BFGTO98ZQdkEXvacZWa8Gr
depends:
    QuickCheck-2.14.3-EKHs0Bckxv35uqjg7I4YbU base-4.17.2.1
    genvalidity-1.1.1.0-KHJzVlYvoZS2c72CJqjhGY
    genvalidity-property-1.0.0.0-9ScWjfX1Hx08nhVDq1AHVz
    hspec-2.10.10-DfdXuKogMQ7HrNFlqwvlNF
    hspec-core-2.10.10-38lz15eDkOH7kHmMvTOpEK transformers-0.5.6.2
    validity-0.12.1.0-8blRYB3ZnTlItS7HgYARc2

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
